@@ -10,22 +10,6 @@ class CreateInstanceError(Exception):
     pass
 
 
-class Data(object):
-    '''
-    Emulates behaviour of ``_value`` but can hold additional data.
-
-    I'm happy to use an already existing implementation that is out there. But
-    for now this serves very well.
-    '''
-    def __init__(self, *args, **kwargs):
-        self._value__ = args.pop(0)
-        self._list = args
-        self._dict = kwargs
-
-    def __getattr__(self, attr):
-        return getattr(self._value__, attr)
-
-
 class Link(object):
     '''
     Handles logic of following or generating foreignkeys and m2m relations.
@@ -76,13 +60,13 @@ class Link(object):
 
 class AutoFixture(object):
     '''
-    We don't support the following fields yet:
+    .. We don't support the following fields yet:
 
         * ``XMLField``
         * ``FileField``
         * ``ImageField``
 
-    Patches are welcome.
+        Patches are welcome.
     '''
     class IGNORE_FIELD(object):
         pass
@@ -122,47 +106,44 @@ class AutoFixture(object):
             follow_m2m=None, generate_m2m=None):
         '''
         Parameters:
-            ``model``:
+            ``model``: A model class which is used to create the test data.
 
             ``field_values``: A dictionary with field names of ``model`` as
-                keys. Values may be static values that are assigned to the
-                field or a ``Generator`` instance that generates a value on the
-                fly.
+            keys. Values may be static values that are assigned to the field,
+            a ``Generator`` instance that generates a value on the fly or a
+            callable which takes no arguments and returns the wanted value.
 
             ``none_chance``: The chance (between 0 and 1, 1 equals 100%) to
             assign ``None`` to nullable fields.
 
             ``overwrite_defaults``: All default values of fields are preserved
-                by default. If set to ``True``, default values will be
-                generated by a matching ``Generator``.
+            by default. If set to ``True``, default values will be treated
+            like any other field.
 
             ``constraints``: A list of callables. The constraints are used to
-                verify if the created model instance may be used. The callable
-                gets the actual model as first and the instance as second
-                parameter. The instance is not populated yet at this moment.
-                The callable may raise an ``InvalidConstraint`` exception to
-                indicate which fields violate the constraint.
+            verify if the created model instance may be used. The callable
+            gets the actual model as first and the instance as second
+            parameter. The instance is not populated yet at this moment.  The
+            callable may raise an :exc:`InvalidConstraint` exception to
+            indicate which fields violate the constraint.
 
             ``follow_fk``: A boolean value indicating if foreign keys should be
-                set to random, already existing, instances of the related
-                model. Default is ``True``.
+            set to random, already existing, instances of the related model.
 
             ``generate_fk``: A boolean which indicates if related models should
-                also be created with random values. Default is ``False``. The
-                ``follow_fk`` parameter will be ignored if this one is set to
-                ``True``.
+            also be created with random values. The *follow_fk* parameter will
+            be ignored if *generate_fk* is set to ``True``.
 
             ``follow_m2m``: A tuple containing minium and maximum of model
-                instances that are assigned to ``ManyToManyField``. No new
-                instances will be created. Default is (1, 5).
-                You can ignore ``ManyToManyField`` fields by setting this
-                parameter to ``False``.
+            instances that are assigned to ``ManyToManyField``. No new
+            instances will be created. Default is (1, 5).  You can ignore
+            ``ManyToManyField`` fields by setting this parameter to ``False``.
 
             ``generate_m2m``: A tuple containing minimum and maximum number of
-                model instance that are newly created and assigned to the
-                ``ManyToManyField``. Default is ``False`` which disables the
-                generation of new related instances. The value of
-                ``follow_m2m`` will be ignored if this parameter is set.
+            model instance that are newly created and assigned to the
+            ``ManyToManyField``. Default is ``False`` which disables the
+            generation of new related instances. The value of ``follow_m2m``
+            will be ignored if this parameter is set.
         '''
         self.model = model
         self.field_values = self.__class__.field_values.copy()
@@ -211,14 +192,25 @@ class AutoFixture(object):
         self.prepare_class()
 
     def prepare_class(self):
+        '''
+        This method is called after the :meth:`__init__` method. It has no
+        semantic by default.
+        '''
         pass
 
-    def add_constraint(self, constraint):
-        self.constraints.append(constraint)
-
     def add_field_value(self, name, value):
+        '''
+        Pass a static *value* that should be assigned to the field called
+        *name*. *value* may be a :ref:`Generator <Generator>` instance.
+        '''
         self.field_values[name] = value
 
+    def add_constraint(self, constraint):
+        '''
+        Add a *constraint* to the autofixture.
+        '''
+        self.constraints.append(constraint)
+
     def get_generator(self, field):
         '''
         Return a value generator based on the field instance that is passed to
@@ -239,6 +231,8 @@ class AutoFixture(object):
                 return value
             elif isinstance(value, AutoFixture):
                 return generators.InstanceGenerator(autofixture=value)
+            elif callable(value):
+                return generators.CallableGenerator(value=value)
             return generators.StaticGenerator(value=value)
 
         if field.null:
@@ -316,6 +310,7 @@ class AutoFixture(object):
                 return generators.LoremSentenceGenerator(
                     common=False,
                     max_length=field.max_length)
+            else:
                 generator = generators.StringGenerator
             return generator(max_length=field.max_length)
         if isinstance(field, fields.DecimalField):
@@ -335,7 +330,7 @@ class AutoFixture(object):
 
     def get_value(self, field):
         '''
-        Return a random value that can be assigned to the passed field
+        Return a random value that can be assigned to the passed *field*
         instance.
         '''
         if field not in self._field_generators:
@@ -417,9 +412,21 @@ class AutoFixture(object):
         return recalc_fields
 
     def post_process_instance(self, instance):
+        '''
+        Overwrite this method to modify the created *instance* at the last
+        possible moment. It gets the generated *instance* and must return the
+        modified instance.
+        '''
         return instance
 
     def create_one(self, commit=True):
+        '''
+        Create and return one model instance. If *commit* is ``False`` the
+        instance will not be saved and many to many relations will not be
+        processed.
+
+        May raise :exc:`CreateInstanceError` if constraints are not satisfied.
+        '''
         tries = self.tries
         instance = self.model()
         process = instance._meta.fields
@@ -452,9 +459,13 @@ class AutoFixture(object):
 
     def create(self, count=1, commit=True):
         '''
-        Create and return ``count`` model instances.
+        Create and return ``count`` model instances. If *commit* is ``False``
+        the instances will not be saved and many to many relations will not be
+        processed.
 
         May raise ``CreateInstanceError`` if constraints are not satisfied.
+
+        The method internally calls :meth:`create_one` to generate instances.
         '''
         object_list = []
         for i in xrange(count):
